Welcome to your new DVT project!

### Using the starter project

Try running the following commands:
- dvt run
- dvt test

### Resources:
- Learn more about DVT at [github.com/heshamh96/dvt-ce](https://github.com/heshamh96/dvt-ce)
- For available database adapters, see the [dbt adapter docs](https://docs.getdbt.com/docs/available-adapters)
- Join the [DVT Discord](https://discord.gg/UjQcxJXAQp) for discussions and support
